Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(287)

Unified Diff: webkit/glue/webpreferences.cc

Issue 201048: Support running tests under LayoutTests/http/tests/local as local file, in or... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 11 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webkit/glue/webpreferences.cc
===================================================================
--- webkit/glue/webpreferences.cc (revision 25942)
+++ webkit/glue/webpreferences.cc (working copy)
@@ -64,9 +64,11 @@
// Turn this on to cause WebCore to paint the resize corner for us.
settings->setShouldPaintCustomScrollbars(true);
- // Mitigate attacks from local HTML files by not granting file:// URLs
- // universal access.
- settings->setAllowUniversalAccessFromFileURLs(false);
+ // By default, allow_universal_access_from_file_urls is set to false and thus
+ // we mitigate attacks from local HTML files by not granting file:// URLs
+ // universal access. Only test shell will enable this.
+ settings->setAllowUniversalAccessFromFileURLs(
+ allow_universal_access_from_file_urls);
// We prevent WebKit from checking if it needs to add a "text direction"
// submenu to a context menu. it is not only because we don't need the result

Powered by Google App Engine
This is Rietveld 408576698